@@ -32,7 +32,7 @@ package Apache2::AMFWURFLFilter;
   # 
 
   use vars qw($VERSION);
-  $VERSION= "3.11";
+  $VERSION= "3.12";
   my $CommonLib = new Apache2::AMFCommonLib ();
  
   my %Capability;
@@ -97,6 +97,7 @@ package Apache2::AMFWURFLFilter;
   $MobileArray{'bolt'}='mobile';
   $MobileArray{'nintendo'}='mobile';
   $MobileArray{'xv6875.1'}='mobile';
+  $MobileArray{'nokia'}='mobile';
   $PCArray{'msie'}='msie';
   $PCArray{'msie 5'}='msie_5';
   $PCArray{'msie 6'}='msie_6';
@@ -632,7 +633,9 @@ sub handler {
     my %ArrayQuery;
     my $var;
     my $mobile=0;
-
+    if ($user_agent eq "") {
+	$user_agent="no usergnet found";
+    }
     if ($x_user_agent) {
        $user_agent=lc($x_user_agent);
     }	  
